import type { RepairFbVO } from './model';

import type { ID, IDS } from '#/api/common';

import { commonExport } from '#/api/helper';
import { requestClient } from '#/api/request';

enum Api {
  repairFbExport = '/eims/repairFb/export',
  repairFbList = '/eims/repairFb/list',
  root = '/eims/repairFb'
}

/**
 * 查询维修评价列表
 * @param query
 * @returns {*}
 */

export function listRepairFb(params?: any) {
  return requestClient.get<RepairFbVO[]>(Api.repairFbList, { params });
}

/**
 * 查询维修评价详细
 * @param repairFbId
 */
export function getRepairFb(repairFbId: ID) {
  return requestClient.get<RepairFbVO>(`${Api.root}/${repairFbId}`);
}

/**
 * 新增维修评价
 * @param data
 */
export function addRepairFb(data: any) {
  return requestClient.postWithMsg<void>(Api.root, data);
}

/**
 * 修改维修评价
 * @param data
 */
export function updateRepairFb(data: any) {
  return requestClient.putWithMsg<void>(Api.root, data);
}

/**
 * 删除维修评价
 * @param repairFbId
 */
export function delRepairFb(repairFbId: IDS) {
  return requestClient.deleteWithMsg<void>(`${Api.root}/${repairFbId}`);
}
/**
 * 导出
 * @param
 */
export function repairFbExport(data: any) {
  return commonExport(Api.repairFbExport, data);
}
